# Taskframe

This is the python library of Taskframe.ai, The annotation platform for data-scientists.

Taskframe.ai is currently in private beta, please contact us to request an invite.

## Useful links

* [Getting Started: Tutorial Notebook](docs/Getting%20Started%20Tutorial.ipynb)
* [Documentation](https://github.com/Taskframe/taskframe-python/wiki)
